@@ -2,7 +2,7 @@
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
 
-# $Id: test.pl,v 1.38 2006/10/15 23:19:17 jrennie Exp $
+# $Id: test.pl,v 1.39 2006/10/17 02:37:42 jrennie Exp $
 
 my $i = 1;
 BEGIN { 
@@ -142,6 +142,11 @@ $wn->frequency('night#n#2') == 217
 $wn->frequency('cnn#n#1') == 0
     ? print "ok ", $i++, "\n" : print "not ok ", $i++, "\n";
 
+$wn->offset("notaword#n#1");
+my @foo = $wn->getResetError();
+$foo[1] == 2
+    ? print "ok ", $i++, "\n" : print "not ok ", $i++, "\n";
+
 if ($ver eq "2.0")
 {
     ($wn->queryWord('person#n#1', 'deri'))[0] eq 'personify#v#3'
